@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
@@ -21,6 +23,7 @@ import proto  # type: ignore
 from google.cloud.documentai_v1beta3.types import document_schema as gcd_document_schema
 from google.cloud.documentai_v1beta3.types import document as gcd_document
 from google.cloud.documentai_v1beta3.types import document_io
+from google.cloud.documentai_v1beta3.types import evaluation as gcd_evaluation
 from google.cloud.documentai_v1beta3.types import operation_metadata
 from google.cloud.documentai_v1beta3.types import processor as gcd_processor
 from google.cloud.documentai_v1beta3.types import processor_type
@@ -28,6 +31,7 @@ from google.cloud.documentai_v1beta3.types import processor_type
 __protobuf__ = proto.module(
     package="google.cloud.documentai.v1beta3",
     manifest={
+        "ProcessOptions",
         "ProcessRequest",
         "HumanReviewStatus",
         "ProcessResponse",
@@ -64,13 +68,38 @@ __protobuf__ = proto.module(
         "SetDefaultProcessorVersionRequest",
         "SetDefaultProcessorVersionResponse",
         "SetDefaultProcessorVersionMetadata",
+        "TrainProcessorVersionRequest",
+        "TrainProcessorVersionResponse",
+        "TrainProcessorVersionMetadata",
         "ReviewDocumentRequest",
         "ReviewDocumentResponse",
         "ReviewDocumentOperationMetadata",
+        "EvaluateProcessorVersionRequest",
+        "EvaluateProcessorVersionMetadata",
+        "EvaluateProcessorVersionResponse",
+        "GetEvaluationRequest",
+        "ListEvaluationsRequest",
+        "ListEvaluationsResponse",
     },
 )
 
 
+class ProcessOptions(proto.Message):
+    r"""Options for Process API
+
+    Attributes:
+        ocr_config (google.cloud.documentai_v1beta3.types.OcrConfig):
+            Only applicable to "Document OCR Processor".
+            Returns error if set on other processor types.
+    """
+
+    ocr_config: document_io.OcrConfig = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=document_io.OcrConfig,
+    )
+
+
 class ProcessRequest(proto.Message):
     r"""Request message for the process document method.
 
@@ -109,40 +138,49 @@ class ProcessRequest(proto.Message):
             Whether Human Review feature should be
             skipped for this request. Default to false.
         field_mask (google.protobuf.field_mask_pb2.FieldMask):
-            Specifies which fields to include in
-            ProcessResponse's document.
+            Specifies which fields to include in ProcessResponse's
+            document. Only supports top level document and pages field
+            so it must be in the form of ``{document_field_name}`` or
+            ``pages.{page_field_name}``.
+        process_options (google.cloud.documentai_v1beta3.types.ProcessOptions):
+            Inference-time options for the process API
     """
 
-    inline_document = proto.Field(
+    inline_document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="source",
         message=gcd_document.Document,
     )
-    raw_document = proto.Field(
+    raw_document: document_io.RawDocument = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="source",
         message=document_io.RawDocument,
     )
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    document = proto.Field(
+    document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=2,
         message=gcd_document.Document,
     )
-    skip_human_review = proto.Field(
+    skip_human_review: bool = proto.Field(
         proto.BOOL,
         number=3,
     )
-    field_mask = proto.Field(
+    field_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=6,
         message=field_mask_pb2.FieldMask,
     )
+    process_options: "ProcessOptions" = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="ProcessOptions",
+    )
 
 
 class HumanReviewStatus(proto.Message):
@@ -171,16 +209,16 @@ class HumanReviewStatus(proto.Message):
         IN_PROGRESS = 3
         ERROR = 4
 
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=1,
         enum=State,
     )
-    state_message = proto.Field(
+    state_message: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    human_review_operation = proto.Field(
+    human_review_operation: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -205,16 +243,16 @@ class ProcessResponse(proto.Message):
             document.
     """
 
-    document = proto.Field(
+    document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=1,
         message=gcd_document.Document,
     )
-    human_review_operation = proto.Field(
+    human_review_operation: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    human_review_status = proto.Field(
+    human_review_status: "HumanReviewStatus" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="HumanReviewStatus",
@@ -233,7 +271,7 @@ class BatchProcessRequest(proto.Message):
             ``projects/{project}/locations/{location}/processors/{processor}``,
             or
             ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``
-        input_configs (Sequence[google.cloud.documentai_v1beta3.types.BatchProcessRequest.BatchInputConfig]):
+        input_configs (MutableSequence[google.cloud.documentai_v1beta3.types.BatchProcessRequest.BatchInputConfig]):
             The input config for each single document in
             the batch process.
         output_config (google.cloud.documentai_v1beta3.types.BatchProcessRequest.BatchOutputConfig):
@@ -245,6 +283,8 @@ class BatchProcessRequest(proto.Message):
         skip_human_review (bool):
             Whether Human Review feature should be
             skipped for this request. Default to false.
+        process_options (google.cloud.documentai_v1beta3.types.ProcessOptions):
+            Inference-time options for the process API
     """
 
     class BatchInputConfig(proto.Message):
@@ -261,11 +301,11 @@ class BatchProcessRequest(proto.Message):
                 should be application/json.
         """
 
-        gcs_source = proto.Field(
+        gcs_source: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        mime_type = proto.Field(
+        mime_type: str = proto.Field(
             proto.STRING,
             number=2,
         )
@@ -279,39 +319,44 @@ class BatchProcessRequest(proto.Message):
                 processed documents.
         """
 
-        gcs_destination = proto.Field(
+        gcs_destination: str = proto.Field(
             proto.STRING,
             number=1,
         )
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    input_configs = proto.RepeatedField(
+    input_configs: MutableSequence[BatchInputConfig] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=BatchInputConfig,
     )
-    output_config = proto.Field(
+    output_config: BatchOutputConfig = proto.Field(
         proto.MESSAGE,
         number=3,
         message=BatchOutputConfig,
     )
-    input_documents = proto.Field(
+    input_documents: document_io.BatchDocumentsInputConfig = proto.Field(
         proto.MESSAGE,
         number=5,
         message=document_io.BatchDocumentsInputConfig,
     )
-    document_output_config = proto.Field(
+    document_output_config: document_io.DocumentOutputConfig = proto.Field(
         proto.MESSAGE,
         number=6,
         message=document_io.DocumentOutputConfig,
     )
-    skip_human_review = proto.Field(
+    skip_human_review: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
+    process_options: "ProcessOptions" = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="ProcessOptions",
+    )
 
 
 class BatchProcessResponse(proto.Message):
@@ -332,7 +377,7 @@ class BatchProcessMetadata(proto.Message):
             The creation time of the operation.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             The last update time of the operation.
-        individual_process_statuses (Sequence[google.cloud.documentai_v1beta3.types.BatchProcessMetadata.IndividualProcessStatus]):
+        individual_process_statuses (MutableSequence[google.cloud.documentai_v1beta3.types.BatchProcessMetadata.IndividualProcessStatus]):
             The list of response details of each
             document.
     """
@@ -376,49 +421,51 @@ class BatchProcessMetadata(proto.Message):
                 document.
         """
 
-        input_gcs_source = proto.Field(
+        input_gcs_source: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        status = proto.Field(
+        status: status_pb2.Status = proto.Field(
             proto.MESSAGE,
             number=2,
             message=status_pb2.Status,
         )
-        output_gcs_destination = proto.Field(
+        output_gcs_destination: str = proto.Field(
             proto.STRING,
             number=3,
         )
-        human_review_operation = proto.Field(
+        human_review_operation: str = proto.Field(
             proto.STRING,
             number=4,
         )
-        human_review_status = proto.Field(
+        human_review_status: "HumanReviewStatus" = proto.Field(
             proto.MESSAGE,
             number=5,
             message="HumanReviewStatus",
         )
 
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=1,
         enum=State,
     )
-    state_message = proto.Field(
+    state_message: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
     )
-    individual_process_statuses = proto.RepeatedField(
+    individual_process_statuses: MutableSequence[
+        IndividualProcessStatus
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=5,
         message=IndividualProcessStatus,
@@ -436,7 +483,7 @@ class FetchProcessorTypesRequest(proto.Message):
             ``projects/{project}/locations/{location}``
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -446,11 +493,13 @@ class FetchProcessorTypesResponse(proto.Message):
     r"""Response message for fetch processor types.
 
     Attributes:
-        processor_types (Sequence[google.cloud.documentai_v1beta3.types.ProcessorType]):
+        processor_types (MutableSequence[google.cloud.documentai_v1beta3.types.ProcessorType]):
             The list of processor types.
     """
 
-    processor_types = proto.RepeatedField(
+    processor_types: MutableSequence[
+        processor_type.ProcessorType
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=processor_type.ProcessorType,
@@ -476,15 +525,15 @@ class ListProcessorTypesRequest(proto.Message):
             empty if at the end of the list.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -494,7 +543,7 @@ class ListProcessorTypesResponse(proto.Message):
     r"""Response message for list processor types.
 
     Attributes:
-        processor_types (Sequence[google.cloud.documentai_v1beta3.types.ProcessorType]):
+        processor_types (MutableSequence[google.cloud.documentai_v1beta3.types.ProcessorType]):
             The processor types.
         next_page_token (str):
             Points to the next page, otherwise empty.
@@ -504,12 +553,14 @@ class ListProcessorTypesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    processor_types = proto.RepeatedField(
+    processor_types: MutableSequence[
+        processor_type.ProcessorType
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=processor_type.ProcessorType,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -534,15 +585,15 @@ class ListProcessorsRequest(proto.Message):
             next processor.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -552,7 +603,7 @@ class ListProcessorsResponse(proto.Message):
     r"""Response message for list processors.
 
     Attributes:
-        processors (Sequence[google.cloud.documentai_v1beta3.types.Processor]):
+        processors (MutableSequence[google.cloud.documentai_v1beta3.types.Processor]):
             The list of processors.
         next_page_token (str):
             Points to the next processor, otherwise
@@ -563,12 +614,12 @@ class ListProcessorsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    processors = proto.RepeatedField(
+    processors: MutableSequence[gcd_processor.Processor] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gcd_processor.Processor,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -582,7 +633,7 @@ class GetProcessorRequest(proto.Message):
             Required. The processor resource name.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -596,7 +647,7 @@ class GetProcessorVersionRequest(proto.Message):
             Required. The processor resource name.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -622,15 +673,15 @@ class ListProcessorVersionsRequest(proto.Message):
             the next processor version.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -640,7 +691,7 @@ class ListProcessorVersionsResponse(proto.Message):
     r"""Response message for list processors.
 
     Attributes:
-        processor_versions (Sequence[google.cloud.documentai_v1beta3.types.ProcessorVersion]):
+        processor_versions (MutableSequence[google.cloud.documentai_v1beta3.types.ProcessorVersion]):
             The list of processors.
         next_page_token (str):
             Points to the next processor, otherwise
@@ -651,12 +702,14 @@ class ListProcessorVersionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    processor_versions = proto.RepeatedField(
+    processor_versions: MutableSequence[
+        gcd_processor.ProcessorVersion
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gcd_processor.ProcessorVersion,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -671,7 +724,7 @@ class DeleteProcessorVersionRequest(proto.Message):
             to be deleted.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -687,7 +740,7 @@ class DeleteProcessorVersionMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=1,
         message=operation_metadata.CommonOperationMetadata,
@@ -703,7 +756,7 @@ class DeployProcessorVersionRequest(proto.Message):
             to be deployed.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -723,7 +776,7 @@ class DeployProcessorVersionMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=1,
         message=operation_metadata.CommonOperationMetadata,
@@ -739,7 +792,7 @@ class UndeployProcessorVersionRequest(proto.Message):
             to be undeployed.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -759,7 +812,7 @@ class UndeployProcessorVersionMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=1,
         message=operation_metadata.CommonOperationMetadata,
@@ -782,11 +835,11 @@ class CreateProcessorRequest(proto.Message):
             processor is under CMEK if CMEK fields are set.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    processor = proto.Field(
+    processor: gcd_processor.Processor = proto.Field(
         proto.MESSAGE,
         number=2,
         message=gcd_processor.Processor,
@@ -802,7 +855,7 @@ class DeleteProcessorRequest(proto.Message):
             deleted.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -818,7 +871,7 @@ class DeleteProcessorMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=5,
         message=operation_metadata.CommonOperationMetadata,
@@ -834,7 +887,7 @@ class EnableProcessorRequest(proto.Message):
             enabled.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -857,7 +910,7 @@ class EnableProcessorMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=5,
         message=operation_metadata.CommonOperationMetadata,
@@ -873,7 +926,7 @@ class DisableProcessorRequest(proto.Message):
             disabled.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -896,7 +949,7 @@ class DisableProcessorMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=5,
         message=operation_metadata.CommonOperationMetadata,
@@ -918,11 +971,11 @@ class SetDefaultProcessorVersionRequest(proto.Message):
             ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{version}``
     """
 
-    processor = proto.Field(
+    processor: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    default_processor_version = proto.Field(
+    default_processor_version: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -942,13 +995,170 @@ class SetDefaultProcessorVersionMetadata(proto.Message):
             operation.
     """
 
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=1,
         message=operation_metadata.CommonOperationMetadata,
     )
 
 
+class TrainProcessorVersionRequest(proto.Message):
+    r"""Request message for the create processor version method.
+
+    Attributes:
+        parent (str):
+            Required. The parent (project, location and processor) to
+            create the new version for. Format:
+            ``projects/{project}/locations/{location}/processors/{processor}``.
+        processor_version (google.cloud.documentai_v1beta3.types.ProcessorVersion):
+            Required. The processor version to be
+            created.
+        document_schema (google.cloud.documentai_v1beta3.types.DocumentSchema):
+            Optional. The schema the processor version
+            will be trained with.
+        input_data (google.cloud.documentai_v1beta3.types.TrainProcessorVersionRequest.InputData):
+            Optional. The input data used to train the
+            ``ProcessorVersion``.
+        base_processor_version (str):
+            Optional. The processor version to use as a base for
+            training. This processor version must be a child of
+            ``parent``. Format:
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``.
+    """
+
+    class InputData(proto.Message):
+        r"""The input data used to train a new ``ProcessorVersion``.
+
+        Attributes:
+            training_documents (google.cloud.documentai_v1beta3.types.BatchDocumentsInputConfig):
+                The documents used for training the new
+                version.
+            test_documents (google.cloud.documentai_v1beta3.types.BatchDocumentsInputConfig):
+                The documents used for testing the trained
+                version.
+        """
+
+        training_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message=document_io.BatchDocumentsInputConfig,
+        )
+        test_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            message=document_io.BatchDocumentsInputConfig,
+        )
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    processor_version: gcd_processor.ProcessorVersion = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_processor.ProcessorVersion,
+    )
+    document_schema: gcd_document_schema.DocumentSchema = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=gcd_document_schema.DocumentSchema,
+    )
+    input_data: InputData = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=InputData,
+    )
+    base_processor_version: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+
+
+class TrainProcessorVersionResponse(proto.Message):
+    r"""The response for the TrainProcessorVersion method.
+
+    Attributes:
+        processor_version (str):
+            The resource name of the processor version
+            produced by training.
+    """
+
+    processor_version: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class TrainProcessorVersionMetadata(proto.Message):
+    r"""The metadata that represents a processor version being
+    created.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+        training_dataset_validation (google.cloud.documentai_v1beta3.types.TrainProcessorVersionMetadata.DatasetValidation):
+            The training dataset validation information.
+        test_dataset_validation (google.cloud.documentai_v1beta3.types.TrainProcessorVersionMetadata.DatasetValidation):
+            The test dataset validation information.
+    """
+
+    class DatasetValidation(proto.Message):
+        r"""The dataset validation information.
+        This includes any and all errors with documents and the dataset.
+
+        Attributes:
+            document_error_count (int):
+                The total number of document errors.
+            dataset_error_count (int):
+                The total number of dataset errors.
+            document_errors (MutableSequence[google.rpc.status_pb2.Status]):
+                Error information pertaining to specific
+                documents. A maximum of 10 document errors will
+                be returned. Any document with errors will not
+                be used throughout training.
+            dataset_errors (MutableSequence[google.rpc.status_pb2.Status]):
+                Error information for the dataset as a whole.
+                A maximum of 10 dataset errors will be returned.
+                A single dataset error is terminal for training.
+        """
+
+        document_error_count: int = proto.Field(
+            proto.INT32,
+            number=3,
+        )
+        dataset_error_count: int = proto.Field(
+            proto.INT32,
+            number=4,
+        )
+        document_errors: MutableSequence[status_pb2.Status] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=1,
+            message=status_pb2.Status,
+        )
+        dataset_errors: MutableSequence[status_pb2.Status] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message=status_pb2.Status,
+        )
+
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=operation_metadata.CommonOperationMetadata,
+    )
+    training_dataset_validation: DatasetValidation = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=DatasetValidation,
+    )
+    test_dataset_validation: DatasetValidation = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=DatasetValidation,
+    )
+
+
 class ReviewDocumentRequest(proto.Message):
     r"""Request message for review document method.
 
@@ -979,31 +1189,31 @@ class ReviewDocumentRequest(proto.Message):
         DEFAULT = 0
         URGENT = 1
 
-    inline_document = proto.Field(
+    inline_document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="source",
         message=gcd_document.Document,
     )
-    human_review_config = proto.Field(
+    human_review_config: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    document = proto.Field(
+    document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=2,
         message=gcd_document.Document,
     )
-    enable_schema_validation = proto.Field(
+    enable_schema_validation: bool = proto.Field(
         proto.BOOL,
         number=3,
     )
-    priority = proto.Field(
+    priority: Priority = proto.Field(
         proto.ENUM,
         number=5,
         enum=Priority,
     )
-    document_schema = proto.Field(
+    document_schema: gcd_document_schema.DocumentSchema = proto.Field(
         proto.MESSAGE,
         number=6,
         message=gcd_document_schema.DocumentSchema,
@@ -1030,16 +1240,16 @@ class ReviewDocumentResponse(proto.Message):
         REJECTED = 1
         SUCCEEDED = 2
 
-    gcs_destination = proto.Field(
+    gcs_destination: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=2,
         enum=State,
     )
-    rejection_reason = proto.Field(
+    rejection_reason: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -1076,34 +1286,168 @@ class ReviewDocumentOperationMetadata(proto.Message):
         FAILED = 4
         CANCELLED = 5
 
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=1,
         enum=State,
     )
-    state_message = proto.Field(
+    state_message: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
     )
-    common_metadata = proto.Field(
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
         proto.MESSAGE,
         number=5,
         message=operation_metadata.CommonOperationMetadata,
     )
-    question_id = proto.Field(
+    question_id: str = proto.Field(
         proto.STRING,
         number=6,
     )
 
 
+class EvaluateProcessorVersionRequest(proto.Message):
+    r"""Evaluates the given ProcessorVersion against the supplied
+    documents.
+
+    Attributes:
+        processor_version (str):
+            Required. The resource name of the
+            [ProcessorVersion][google.cloud.documentai.v1beta3.ProcessorVersion]
+            to evaluate.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``
+        evaluation_documents (google.cloud.documentai_v1beta3.types.BatchDocumentsInputConfig):
+            Optional. The documents used in the
+            evaluation. If unspecified, use the processor's
+            dataset as evaluation input.
+    """
+
+    processor_version: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    evaluation_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=document_io.BatchDocumentsInputConfig,
+    )
+
+
+class EvaluateProcessorVersionMetadata(proto.Message):
+    r"""Metadata of the EvaluateProcessorVersion method.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=operation_metadata.CommonOperationMetadata,
+    )
+
+
+class EvaluateProcessorVersionResponse(proto.Message):
+    r"""Metadata of the EvaluateProcessorVersion method.
+
+    Attributes:
+        evaluation (str):
+            The resource name of the created evaluation.
+    """
+
+    evaluation: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
+class GetEvaluationRequest(proto.Message):
+    r"""Retrieves a specific Evaluation.
+
+    Attributes:
+        name (str):
+            Required. The resource name of the
+            [Evaluation][google.cloud.documentai.v1beta3.Evaluation] to
+            get.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}/evaluations/{evaluation}``
+    """
+
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class ListEvaluationsRequest(proto.Message):
+    r"""Retrieves a list of evaluations for a given ProcessorVersion.
+
+    Attributes:
+        parent (str):
+            Required. The resource name of the
+            [ProcessorVersion][google.cloud.documentai.v1beta3.ProcessorVersion]
+            to list evaluations for.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``
+        page_size (int):
+            The standard list page size.
+            If unspecified, at most 5 evaluations will be
+            returned. The maximum value is 100; values above
+            100 will be coerced to 100.
+        page_token (str):
+            A page token, received from a previous ``ListEvaluations``
+            call. Provide this to retrieve the subsequent page.
+    """
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+
+
+class ListEvaluationsResponse(proto.Message):
+    r"""The response from ListEvaluations.
+
+    Attributes:
+        evaluations (MutableSequence[google.cloud.documentai_v1beta3.types.Evaluation]):
+            The evaluations requested.
+        next_page_token (str):
+            A token, which can be sent as ``page_token`` to retrieve the
+            next page. If this field is omitted, there are no subsequent
+            pages.
+    """
+
+    @property
+    def raw_page(self):
+        return self
+
+    evaluations: MutableSequence[gcd_evaluation.Evaluation] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_evaluation.Evaluation,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
